@@ -1,7 +1,7 @@
 //
 //  Mixer.app
 // 
-//  Copyright (c) 1998, 1999 Per Liden
+//  Copyright (c) 1998-2000 Per Liden
 // 
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -25,44 +25,55 @@
 #include <X11/Xlib.h>
 
 #define APPNAME		"Mixer.app"
-#define VERSION		"1.4.0"
+#define VERSION		"1.5.0"
 #define INSTANCENAME	"mixer_app"
 #define CLASSNAME	"Mixer_app"
 #define MIXERDEVICE	"/dev/mixer"
+#define SETTINGS        "/GNUstep/Defaults/Mixer"
+
+#define LABEL_X		4
+#define LABEL_Y		54
+#define LABEL_FONT	"-*-helvetica-medium-r-*-*-8-*-*-*-*-*-*-*"
+
 #define LED_X		57
 #define LED_Y		59
 #define BUTTON_MIN	45
 #define BUTTON_MAX	6
 
-class Mixer {
- public:
-    Mixer(int argc, char** argv);
-    ~Mixer();
-    void run();
+class Mixer 
+{
+public:
+   Mixer(int argc, char** argv);
+   ~Mixer() {};
+   void run();
+   void saveVolumeSettings();
 
- private:
-    Mixer();  // Disabled constructor
-    void showHelp();
-    void checkArgument(char* option, char* arg);
-    void showErrorLed();
-    void getVolume();
-    void setVolume(int button, int volume);
-    void mute(int button);
-    void setButtonPosition(int button, int relativePosition);
+private:
+   void tryHelp(char* appname);
+   void showHelp();
+   void checkArgument(char** argv, int argc, int index);
+   void showErrorLed();
+   void getVolume();
+   void setVolume(int button, int volume);
+   void mute(int button);
+   void setButtonPosition(int button, int relativePosition);
+   void loadVolumeSettings();
 
-    Display* mDisplay;
-    Window   mRoot;
-    Window   mAppWin;
-    Window   mIconWin;
-    Window   mButton[3];
-    char*    mMixerDevice;
-    char*    mInstanceName;
-    int      mError;
-    int      mVolumeSource[3];
-    int      mVolume[3];
-    int      mVolumePos[3];
-    int      mVolumeMute[3];
-    int      mWheelButton;
+   Display* mDisplay;
+   Window   mRoot;
+   Window   mAppWin;
+   Window   mIconWin;
+   Window   mButton[3];
+   char*    mMixerDevice;
+   char*    mInstanceName;
+   char*    mLabelText;
+   char*    mSettingsFile;
+   int      mError;
+   int      mVolumeSource[3];
+   int      mVolume[3];
+   int      mVolumePos[3];
+   int      mVolumeMute[3];
+   int      mWheelButton;
 };
 
 #endif
