@@ -1,7 +1,7 @@
 //
 //  Mixer.app
 // 
-//  Copyright (c) 1998, 1999 Per Liden
+//  Copyright (c) 1998-2000 Per Liden
 // 
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -25,20 +25,20 @@
 #include <X11/Xlib.h>
 #include <X11/xpm.h>
 
-class Xpm {
- public:
-    Xpm(Display* display, Window root, char** data);
-    virtual ~Xpm();
-    void setWindowPixmap(Window win);
-    void setWindowPixmapShaped(Window win);
+class Xpm 
+{
+public:
+   Xpm(Display* display, Window root, char** data);
+   virtual ~Xpm();
+   void setWindowPixmap(Window win);
+   void setWindowPixmapShaped(Window win);
+   void drawString(int x, int y, char* text);
 
- private:
-    Xpm();  // Disabled constructor
-
-    Display*      mDisplay;
-    XpmAttributes mAttributes;
-    Pixmap        mImage;
-    Pixmap        mMask;
+private:
+   Display*      mDisplay;
+   XpmAttributes mAttributes;
+   Pixmap        mImage;
+   Pixmap        mMask;
 };
 
 #endif
